

import java.util.*;
import java.awt.*;
import java.applet.Applet;
import java.awt.event.*;
import javax.swing.JLabel;


class Node {
    double x;
    double y;

    double dx;
    double dy;

    boolean fixed;

    String lbl;
}


class Edge {
    int from;
    int to;
	Color color = Color.black;
	
    double len;
	int w, s;
}

class Flow {
    int from;
    int to;
	
	int A[], B[];
    int hopA, hopB;
}

class GraphPanel1 extends Panel
    implements Runnable, MouseListener, MouseMotionListener {
    Graph graph;
    int nnodes;
    Node nodes[] = new Node[60];

    int nedges;
    Edge edges[] = new Edge[100];

	int nflows = 0;
	Flow flows[] = new Flow[3540]; // =60*59
	int C[][] = new int[200][200];
	int dmdm[][] = new int[60][60];
	
    Thread relaxer;
    boolean stress;
    boolean random;

    GraphPanel1(Graph graph) {
	this.graph = graph;
	addMouseListener(this);
    }

    int findNode(String lbl) {
       // System.out.print(lbl);
	for (int i = 0 ; i < nnodes ; i++) {
		if (nodes[i]!=null){
			if (nodes[i].lbl.equals(lbl)) {
				return i;
			}
		}
	}
	return addNode(lbl);
    }
    int addNode(String lbl) {
	Node n = new Node();
	n.x = 10 + 380*Math.random();
	n.y = 10 + 380*Math.random();
	n.lbl = lbl;
	nodes[nnodes] = n;
	return nnodes++;
    }
    void addEdge(String from, String to, int len) {
		Edge e = new Edge();
		e.from = findNode(from);
		e.to = findNode(to);
		e.len = len;
		edges[nedges++] = e;
    }

	void addFlow(int from, int to, String str1, String str2) {
		Flow f = new Flow();
		f.A = new int[nedges];
		f.B = new int[nedges];
		f.from = from; 
		f.to = to;
               // System.out.println("nflows="+nflows);
		dmdm[from][to] = nflows;
		dmdm[to][from] = nflows;
		for (int k=0; k<nedges; k++){
			f.A[k] = Integer.valueOf(str1.substring(k,k+1)).intValue(); 
                       // System.out.println("A["+k+"]="+f.A[k]);
			f.hopA += f.A[k];
			f.B[k] = Integer.valueOf(str2.substring(k,k+1)).intValue(); 
                        //System.out.print("B["+k+"]="+f.B[k]);
			f.hopB += f.B[k];
		}
		flows[nflows] = f;
		nflows ++;
	}
	
	void showFlow(Node n1, Node n2) {
		int i1 = findNode(n1.lbl);
		int i2 = findNode(n2.lbl);
                
		int fn = dmdm[i1][i2];
		Flow f = flows[fn];
               //Flow f=new Flow(fn);
                //System.out.println(nedges);
		for (int i = 0 ; i < nedges ; i++) {
                  //System.out.println("in showFlow A[i]="+f.A[i]);
	   	   	  if (f.A[i]==1 )
				edges[i].color = workColor;
			else if (f.B[i]==1)
				edges[i].color = backupColor;
			else
				edges[i].color = arcColor1;
		}
		offgraphics.drawImage(offscreen, 0, 0, null);
                int mul=0;
               double m=Math.random()/10;
               String s=Double.toString(m);
               String s1=s.substring(0,6);
                graph.t1.setText(s1);
                String s2=s1.substring(4,5);
                int leng=Integer.parseInt(s2);
                leng=leng*50;
                graph.t2.setText(""+leng);
	}
	
	
	public void run() {
        Thread me = Thread.currentThread();
	while (relaxer == me) {
	    relax();
	    if (random && (Math.random() < 0.03)) {
		Node n = nodes[(int)(Math.random() * nnodes)];
		if (!n.fixed) {
		    n.x += 100*Math.random() - 50;
		    n.y += 100*Math.random() - 50;
		}
		//graph.play(graph.getCodeBase(), "audio/drip.au");
	    }
	    try {
		Thread.sleep(100);
	    } catch (InterruptedException e) {
		break;
	    }
	}
    }

    synchronized void relax() {
	for (int i = 0 ; i < nedges ; i++) {
	    Edge e = edges[i];
	    double vx = nodes[e.to].x - nodes[e.from].x;
	    double vy = nodes[e.to].y - nodes[e.from].y;
	    double len = Math.sqrt(vx * vx + vy * vy);
            len = (len == 0) ? .0001 : len;
	    double f = (edges[i].len - len) / (len * 3);
	    double dx = f * vx;
	    double dy = f * vy;

	    nodes[e.to].dx += dx;
	    nodes[e.to].dy += dy;
	    nodes[e.from].dx += -dx;
	    nodes[e.from].dy += -dy;
	}

	for (int i = 0 ; i < nnodes ; i++) {
	    Node n1 = nodes[i];
	    double dx = 0;
	    double dy = 0;

	    for (int j = 0 ; j < nnodes ; j++) {
		if (i == j) {
		    continue;
		}
		Node n2 = nodes[j];
		double vx = n1.x - n2.x;
		double vy = n1.y - n2.y;
		double len = vx * vx + vy * vy;
		if (len == 0) {
		    dx += Math.random();
		    dy += Math.random();
		} else if (len < 100*100) {
		    dx += vx / len;
		    dy += vy / len;
		}
	    }
	    double dlen = dx * dx + dy * dy;
	    if (dlen > 0) {
		dlen = Math.sqrt(dlen) / 2;
		n1.dx += dx / dlen;
		n1.dy += dy / dlen;
	    }
	}

	Dimension d = getSize();
	for (int i = 0 ; i < nnodes ; i++) {
	    Node n = nodes[i];
	    if (!n.fixed) {
		n.x += Math.max(-5, Math.min(5, n.dx));
		n.y += Math.max(-5, Math.min(5, n.dy));
            }
            if (n.x < 0) {
                n.x = 0;
            } else if (n.x > d.width) {
                n.x = d.width;
            }
            if (n.y < 0) {
                n.y = 0;
            } else if (n.y > d.height) {
                n.y = d.height;
            }
	    n.dx /= 2;
	    n.dy /= 2;
	}
	repaint();
    }

    Node pick;
    boolean pickfixed;
    Image offscreen;
    Dimension offscreensize;
    Graphics offgraphics;

    final Color fixedColor = Color.white;
    final Color selectColor = Color.pink;
    final Color edgeColor = Color.BLACK;
    final Color nodeColor = new Color(150, 120, 100);
    final Color stressColor = new Color(150, 120, 100);
    final Color arcColor1 = Color.black;
    final Color arcColor2 = Color.pink;
    final Color arcColor3 = Color.red;
    final Color workColor = Color.green;
    final Color backupColor = Color.red;
    
    public void paintNode(Graphics g, Node n, FontMetrics fm) {
		int x = (int)n.x;
		int y = (int)n.y;
		g.setColor((n == pick) ? selectColor : (n.fixed ? fixedColor : nodeColor));
		int w = fm.stringWidth(n.lbl) + 10;
		int h = fm.getHeight() + 4;
		g.fillRect(x - w/2, y - h / 2, w, h);
		g.setColor(Color.black);
		g.drawRect(x - w/2, y - h / 2, w-1, h-1);
		g.drawString(n.lbl, x - (w-10)/2, (y - (h-4)/2) + fm.getAscent());
    }

    public synchronized void update(Graphics g) {
		Dimension d = getSize();
		if ((offscreen == null) || (d.width != offscreensize.width) || (d.height != offscreensize.height)) {
		    offscreen = createImage(d.width, d.height);
		    offscreensize = d;
			if (offgraphics != null) {
				offgraphics.dispose();
			}
			offgraphics = offscreen.getGraphics();
			offgraphics.setFont(getFont());
		}

		offgraphics.setColor(getBackground());
		
                offgraphics.fillRect(0, 0, d.width, d.height);
		for (int i = 0 ; i < nedges ; i++) {
		    Edge e = edges[i];
		    int x1 = (int)nodes[e.from].x;
		    int y1 = (int)nodes[e.from].y;
		    int x2 = (int)nodes[e.to].x;
			int y2 = (int)nodes[e.to].y;
		    int len = (int)Math.abs(Math.sqrt((x1-x2)*(x1-x2) + (y1-y2)*(y1-y2)) - e.len);
			offgraphics.setColor(e.color) ;
                        
                        
                        
			offgraphics.drawLine(x1, y1, x2, y2);
			if (stress) {
			String lbl = String.valueOf(len);
			offgraphics.setColor(stressColor);
			offgraphics.drawString(lbl, x1 + (x2-x1)/2, y1 + (y2-y1)/2);
			offgraphics.setColor(edgeColor);
			}
		}
	
		FontMetrics fm = offgraphics.getFontMetrics();
		for (int i = 0 ; i < nnodes ; i++) {
			paintNode(offgraphics, nodes[i], fm);
		}
		g.drawImage(offscreen, 0, 0, null);
	}

    //1.1 event handling
    public void mouseClicked(MouseEvent e) {
       
      
		if (graph.topo)	{
		}
		else{
		double bestdist = Double.MAX_VALUE;
		int x = e.getX();
		int y = e.getY();
		for (int i = 0 ; i < nnodes ; i++) {
			Node n = nodes[i];
			double dist = (n.x - x) * (n.x - x) + (n.y - y) * (n.y - y);
			if (dist < bestdist) {
			pick = n;
			bestdist = dist;
			}
		}
		pickfixed = pick.fixed;
		pick.fixed = ! pick.fixed;
		pick.x = x;
		pick.y = y;
            
              
                
                repaint();
                
		e.consume();
		}
    
    }

    public void mousePressed(MouseEvent e) {
        
        
             addMouseMotionListener(this);
	        	if (graph.topo)	{
            
			                  double bestdist = Double.MAX_VALUE;
			                  int x = e.getX();
			                  int y = e.getY();
                                          //System.out.println("value for pick"+pick);
			                   if (pick != null)
                                            {
			                	Node p2 = pick;
				                for (int i = 0 ; i < nnodes ; i++) 
                                                 {
					            Node n = nodes[i];
					             double dist = (n.x - x) * (n.x - x) + (n.y - y) * (n.y - y);
					              if (dist < bestdist) 
                                                       {
					          	p2 = n;
						        bestdist = dist;
					               }
				                  }
				
                                                if (pick != p2)
                                                showFlow(pick, p2);
				                else 
					        pick = null;
			                       } 
                                           else
                                             {
				               for (int i = 0 ; i < nnodes ; i++)
                                                {
					         Node n = nodes[i];
					         double dist = (n.x - x) * (n.x - x) + (n.y - y) * (n.y - y);
					          if (dist < bestdist)
                                                  {
						   pick = n;
						   bestdist = dist;
					           }
				                 }
			                        }
			
		                     }
                                    else
                                    {
	                             double bestdist = Double.MAX_VALUE;
	                             int x = e.getX();
	                             int y = e.getY();
	                             for (int i = 0 ; i < nnodes ; i++)
                                     {
	                               Node n = nodes[i];
	                                double dist = (n.x - x) * (n.x - x) + (n.y - y) * (n.y - y);
	                                 if (dist < bestdist)
                                          {
		                           pick = n;
		                           bestdist = dist;
	                                   }
	                               }
	                              pickfixed = pick.fixed;
	                              pick.fixed = true;
	                              pick.x = x;
	                              pick.y = y;
	                               
                                      repaint();
	                              e.consume();
	                        }
        
    
    
    }
    public void mouseReleased(MouseEvent e) {
   
        removeMouseMotionListener(this);
		if (graph.topo)	{
		}
		else {
        if (pick != null) {
            pick.x = e.getX();
            pick.y = e.getY();
            pick.fixed = pickfixed;
            if (!graph.topo)
				pick = null;
        }
	repaint();
	e.consume();
		}
  
        }

	public void mouseEntered(MouseEvent e) {
    }

    public void mouseExited(MouseEvent e) {
    }

    public void mouseDragged(MouseEvent e) {
		if (graph.topo){
		}else {
			pick.x = e.getX();
			pick.y = e.getY();
			repaint();
			e.consume();
		}	
	}

    public void mouseMoved(MouseEvent e) {
    }

    public void start() {
	relaxer = new Thread(this);
	relaxer.start();
    }

    public void stop() {
	relaxer = null;
    }
}


public class Graph extends Applet implements ActionListener, ItemListener {
    
     public int TIS,BPL;
    GraphPanel1 panel;
    Panel controlPanel;

    Button state = new Button(" Topology ");
    Button scramble = new Button("Scramble");
    Button shake = new Button("Shake");
    Checkbox stress = new Checkbox("Stress");
    Checkbox random = new Checkbox("Random");
    Label failure=new Label("Dual failure");
    Label backup=new Label("Backup Path");
    Label Time=new Label("TIS");
    TextField t1=new TextField("       ");
    Label BPLength=new Label("BPLength");
    TextField t2=new TextField("      ");
   // Button next = new Button("Save");
	//TextField loc = new TextField("location",12);

	boolean topo = false;
	
    public void init(){
        try{
                setBackground(Color.DARK_GRAY);
		setLayout(new BorderLayout());
                 
		panel = new GraphPanel1(this);
		add("Center", panel);
		controlPanel = new Panel();
		add("North", controlPanel);

		controlPanel.add(state); state.addActionListener(this);
                state.setBackground(Color.DARK_GRAY);state.setForeground(new Color(150, 120, 100));
		controlPanel.add(scramble); scramble.addActionListener(this);
                scramble.setBackground(Color.DARK_GRAY);scramble.setForeground(new Color(150, 120, 100));
		controlPanel.add(shake); shake.addActionListener(this);
                shake.setBackground(Color.DARK_GRAY);shake.setForeground(new Color(150, 120, 100));
		controlPanel.add(stress); stress.addItemListener(this);
                stress.setForeground(new Color(150, 120, 100));
	        controlPanel.add(random); random.addItemListener(this);
                random.setForeground(new Color(150, 120, 100));
                controlPanel.add(failure); //failure.addItemListener(this);
                  controlPanel.add(backup);// random.addItemListener(this);
                failure.setForeground(Color.RED);
                backup.setForeground(Color.GREEN);
                controlPanel.add(Time);Time.setForeground(new Color(150, 120, 100));
                controlPanel.add(t1);
                t1.setSize(20,25);
                t1.setEditable(false);t1.setForeground(Color.BLUE);
                controlPanel.add(BPLength);BPLength.setForeground(new Color(150, 120, 100));
                controlPanel.add(t2); 
                t2.setSize(20,25);
                t2.setEditable(false);t2.setForeground(Color.BLUE);
               // controlPanel.add(next);next.setForeground(new Color(150, 120, 100));
               // next.setBackground(Color.DARK_GRAY);next.addActionListener(this);
		//controlPanel.add(loc); 
		//String networks="";
                
		
		String net ="18";//getParameter("");
		if (net != null){
			int nn = Integer.valueOf(net).intValue();
			for (int i =0; i < nn; i++) 
				panel.addNode(Integer.toString(i+1));
		}
			//"17/30:30,9/20:70,16/60:80,2/220:340,11/220:30"
	       String fixed ="";// getParameter("fixed");
		 if (fixed != null){
		 for (StringTokenizer t = new StringTokenizer(fixed, ",") ;t.hasMoreTokens() ;)
                 {
		   String str = t.nextToken();
		   int i = str.indexOf('/');
		   if (i > 0) 
                      {
			Node n = panel.nodes[panel.findNode(str.substring(0,i))];
			str = str.substring(i+1);
			n.fixed = true;
			int j = str.indexOf(':');
			if (j > 0)
                        {
			n.x = Integer.valueOf(str.substring(0,j)).intValue();
			str = str.substring(j+1);
			n.y = Integer.valueOf(str).intValue();
			}
		     }
		}
		}
               //"1-2/80,1-3/80,1-4/80,2-3/80,2-4/80,3-4/80"
               //'C-N1,C-N2,C-N3,C-NX,N1-N2/M12,N2-N3/M23,N3-NX/M3X,...'
		//"1-8/10,1-11/40,1-13/80,1-3/44,2-14/4,2-12/14,2-18/00,3-17/32,3-16/22,3-5/10,3-13/14,4-7/12,4-15/16,4-18/10,5-3/10,5-16/12,5-15/4,6-8/14,6-11/6,7-9/12,9-17/16,10-11/26,10-14/30,10-12/30,12-18/38,13-14/12,14-15/28,16-17/16";
		String edges ="1-8/10,1-11/40,1-13/80,1-3/44,2-14/4,2-12/14,2-18/00,3-17/32,3-16/22,3-15/10,3-13/14,4-7/12,4-15/16,4-18/10,5-3/10,5-16/12,5-15/4,6-8/14,6-11/6,6-12/50,7-9/12,7-5/50,8-14/30,9-17/16,9-15/25,10-11/26,10-14/30,10-12/30,12-18/38,13-14/12,14-15/28,16-17/16";//getParameter("Edge-one/Edge-two");
		for (StringTokenizer t = new StringTokenizer(edges, ",");t.hasMoreTokens() ; ) {
			String str = t.nextToken();
			int i = str.indexOf('-');
			if (i > 0) 
                        {
			int len = 50;
			int j = str.indexOf('/');
                        
			if (j > 0) 
                        {
			    len = Integer.valueOf(str.substring(j+1)).intValue();
			    str = str.substring(0, j);
			    }
			panel.addEdge(str.substring(0,i), str.substring(i+1), len);
			}
	    }	
	
		Dimension d = getSize();
		String center ="";
                
		/*if (center != null){
		    Node n = panel.nodes[panel.findNode(center)];
		    n.x = d.width / 2;
		    n.y = d.height / 2;
		    n.fixed = true;
		}*/
                //0 0 0 0 0 , 0 0 0 0 0 , 0  0  0 0  0 , 0 0  0  0  0 , 0 0  0  0  0 , 0 0  0  0  0 , 0  0
	//        1 2 3 4 5   6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30  31 32  
                //     100101000000000000000000000000100;200010000000000000000000000000000;300101000000000000000000000001000;400101000000000000000000000001000;500101000000000000000000000001000;600101000000000000000000000001000;700101000000000000000000000001000;800101000000000000000000000001000;900101000000000000000000000001000;10001010000000000000000001000; 11 101000000000000000000000001000;12 01000000000000000000000001000;131010000000000000000000000010;14101000000000000000000000001000; 15101000000000000000000000001000;16101000000000000000000000001000;17101000000000000000000000001000;2-3101000000000000000000000001000;2-4101000000000000000000000001000;2-5000000000000000000000001000;2-611010000000000000000000001000;2-710100000000000000000000001000;2-801000000000000000000000001000;2-941010000000000000000000001000;2-10 1000000000000000000000001000;2-11 01000000000000000000001000;2-12 000000000000000000000001000;2-13 000000000000000000000001000;2-14 000000000000000000000001000;2-15 000000000000000000000001000;2-16 000000000000000000000001000;2-17  00000000000000000000001000; 2-18;                          3 -4101000000000000000000000001000;3-5000000000000000000000001000;3-611010000000000000000000001000;3-710100000000000000000000001000;3-801000000000000000000000001000;3-941010000000000000000000001000;3-10 1000000000000000000000001000;3-11 01000000000000000000001000;3-12 000000000000000000000001000;3-13 000000000000000000000001000;3-14 000000000000000000000001000;3-15 000000000000000000000001000;3-16 000000000000000000000001000;3-17  00000000000000000000001000;3-18                            ;4-5000000000000000000000001000   ;4-611010000000000000000000001000;4-710100000000000000000000001000;4-801000000000000000000000001000;4-941010000000000000000000001000;4-10 1000000000000000000000001000;4-11 01000000000000000000001000;4-12 000000000000000000000001000;4-13 000000000000000000000001000;4-14 000000000000000000000001000;4-15 000000000000000000000001000;4-16 000000000000000000000001000;4-17  00000000000000000000001000;4-18                            ;5-611010000000000000000000001000;5-710100000000000000000000001000;5-801000000000000000000000001000;5-941010000000000000000000001000;5-10 1000000000000000000000001000;5-11 01000000000000000000001000;5-12 000000000000000000000001000;5-13 000000000000000000000001000;5-14 000000000000000000000001000;5-15 000000000000000000000001000;5-16 000000000000000000000001000;5-17  00000000000000000000001000;5-18                              ;6-710100000000000000000000001000;6-801000000000000000000000001000;6-941010000000000000000000001000;6-10 1000000000000000000000001000;6-11 01000000000000000000001000;6-12 000000000000000000000001000;6-13 000000000000000000000001000;6-14 000000000000000000000001000;6-15 000000000000000000000001000;6-16 000000000000000000000001000;6-17  00000000000000000000001000;6-18                            ;7-801000000000000000000000001000;7-941010000000000000000000001000;7-10 1000000000000000000000001000;7-11 01000000000000000000001000;7-12 000000000000000000000001000;7-13 000000000000000000000001000;7-14 000000000000000000000001000;7-15 000000000000000000000001000;7-16 000000000000000000000001000;7-17  00000000000000000000001000;7-18                           ;8-941010000000000000000000001000;8-10 1000000000000000000000001000;8-11 01000000000000000000001000;8-12 000000000000000000000001000;8-13 000000000000000000000001000;8-14 000000000000000000000001000;8-15 000000000000000000000001000;8-16 000000000000000000000001000;8-17  00000000000000000000001000;8-18                              ;9-10 1000000000000000000000001000;9-11 01000000000000000000001000;9-12 000000000000000000000001000;9-13 000000000000000000000001000;9-14 000000000000000000000001000;9-15 000000000000000000000001000;9-16 000000000000000000000001000;9-17  00000000000000000000001000;9-18 "                          ;10-11 010000000000000000000010;10-12 000000000000000000000001000;10-13 0000000000000000000001000;10-14 0000000000000000000001000;10-15 000000000000000000000001000;10-16 000000000000000000000001000;10-17  00000000000000000000001000;10-18                         ;11-12 000000000000000000000001000;11-13 0000000000000000000001000;11-14 0000000000000000000001000;11-15 000000000000000000000001000;11-16 000000000000000000000001000;11-17  00000000000000000000001000;11-18                           ;12-13 0000000000000000000001000;12-14 0000000000000000000001000;12-15 000000000000000000000001000;12-16 000000000000000000000001000;12-17  00000000000000000000001000;12-18                          ;13-14 0000000000000000000001000;13-15 000000000000000000000001000;13-16 000000000000000000000001000;13-17  00000000000000000000001000;13-18                        ;;14-15 000000000000000000000001000;14-16 000000000000000000000001000;14-17  00000000000000000000001000;14-18                      ;15-16 000000000000000000000001000;15-17  00000000000000000000001000;15-18                         ;16-17  00000000000000000000001000;16-18                          ;17-18  
		String path ="00101000000000000000000000000100;00010000000000000000000000000000;00010000000100100000010000000000;00010000000000100000000000000000;10000000000000000100000000000000;00010000000000100000010000000000;10000000000000000000000000000000;00010000000000100000110000000000;01000000000000000000000001000000;01000000000000000000000000000000;10000000000000000101000000000000;00100000000000000000000000000000;00100000000000000000000000000100;00010000000000101000000000000000;00010000100000000000000000000000;00010000100000000000000000000001;10001010000000000000001000000000;00001000001000000000000000000100;00000010000001000000000000000000;00001000000000001000000000000010;00000100000000000001000000000000;00000010000101000000000000000000;00001000000000000000001000000000;00001000000000000000000010000010;00001000000000000000000000100000;00000100000000000011000000000000;00000100000000000000000000000000;00001000000000000000000000000100;00001000000000000000000000000000;00001000000000000000000000000010;00001000000000011000000000000010;00001001001000000000000000000100;00000010000000000000000000000000;00000000010010000000000000000000;00000000000000100000000000000000;00000000001000000100001000000100;00000000000000100000010000000000;00000000001000000000001000000100;00000000010000000000000010000000;00000000001000000000000000100100;00000000001000000110001000000100;00001100001000000000000000000100;00000000001000000000000000000000;00000000001000000000000000000100;00000000010000000000000000000000;00000000100000000000000000000000;00000001000000000000000000000000;00001010001000000000000000000100;00000000000010001000000000000000;00000000000010000100001000000010;00000000000100000000000000000000;00000000000010000000001000000010;00000000000010000000000010000000;00000000000010000000000000100010;00000000000010000110001000000010;00001100000010000000000000000010;00000000000010000000000000000110;00000000000010000000000000000010;00000000000010000000000000000000;00000000000010011000000000000000;00000001010010000000000000000000;00000000000001000000000000000000;00000000000000001100001000000010;00000000000000000000010000000000;00000000000000001000001000000010;00000000000000001000000010000000;00000000000000001000000000100010;00000000000000001110001000000010;00001100000000001000000000000010;00000000001000100000000000000000;00000000000000001000000000000010;00000000000000001000000000000000;00000000000000010000000000000000;00000001000000100000000000000000;00001010000000001000000000000010;00000000000000001100011000000010;00000000000000000100000000000000;00000000000000000100001010000010;00000000000000000100001000100000;00000000000000000010000000000000;00000000000000000001000000000000;00000000000000000100001000000100;00000000000000000100001000000000;00000000000000000100001000000010;00000000000000011100001000000010;00000001010000000100001000000010;00000110000000000001000000000000 ;00000000000000001000011000000010;00000000000000001000010010000000;00000000000000001000010000100010;00000000000000001110011000000010;00001100000000001000010000000010;00000000000000001000010000000110;00000000000000001000010000000010;00000000000000001000010000000000;00000000000000010000010000000000;00000001000000100000010000000000;00001010000000001000010000000010;00000000000000000000001010000010;00000000000000000000001000100000;00000000000000000110000000000000;00000000000000000101000000000000;10100000000000000000000000000000;00000000000000000000001000000000;00000000000000000000001000000010;00000000000000011000001000000010;00000001010000000000001000000010;00001010000000000000001000000000;00000000000000000000000010100010;00000000000000000110001010000010;00001100000000000000000010000010;00000000000000000000000010000110;00000000000000000000000010000010;00000000000000000000000010000000;00000000000000011000000010000000;00000000000000000000000100000000;00001010000000000000000010000010;00000000000000000000000001000000;00001100000000000000000000100000;00000000000000000000000000100100;00000000000000000000000000100000;00000000000000000000000000100010;00000000000000011000000000100010;00000001010000000000000000100010;00001010000000000000000000100000;00000000000000000011000000000000;00000000000000000110001000000100;00000000000000000110001000000000;00000000000000000110001000000010;00000000000000011110001000000010;00000001010000000110001000000100;00001010000000000110001000000000;00001100000000000000000000000100;00001100000000000000000000000000;00001100000000000000000000000010;00001100000000011000000000000010;00001101010000000000000000000010;00000110000000000000000000000000;00000000000000000000000000000100;00000000011000000000000000000000;00000000001000110000000000000000;00000001001000000000000000000000;00001010000000000000000000000100;00000000000000000000000000000010;00000000000000011000000000000010;00000001010000000000000000000010;00001010000000000000000000000000;00000000000000011000000000000000;00000001010000000000000000000000;00001010000000000000000000000010;00000000000000000000000000000001;00001010000000011000000000000010;;00001011001000000000000000000100";//getParameter("work");
		StringTokenizer t1 = new StringTokenizer(path, ";");
                           //  100101000000000000000000000000100;200010000000000000000000000000000;300101000000000000000000000001000;400101000000000000000000000001000;500101000000000000000000000001000;600101000000000000000000000;700101000000000000000000000001000;800101000000000000000000000001000;9001010000000000000000000001000;10001010000000000000000001000;  11101000000000000000000000001000;1201000000000000000000000001000; 131010000000000000000000000010;   14101000000000000000000000001000; 15101000000000000000000000001000;16101000000000000000000000001000;17101000000000000000000000001000;2-3101000000000000000000000001000;2-41010000000000000000000000000;2-5000000000000000000000001000;2-611000000000000000000000001000;2-7101000000000000000000000001000;2-8101000000000000000000000001000;2-91000000000000000000000001000;2-10 1000000000000000000000001000;2-11 1000000000000000000000001000;2-12 00000000000000000000001000;2-13 000000000000000000000001000;2-14 000000000000000000000001000;2-15 000000000000000000000001000;2-16 000000000000000000000001000;2-17 000000000000000000000001000;2-18"                          3 -4101000000000000000000000001000;3-5000000000000000000000001000;3-611010000000000000000000001000;3-710100000000000000000000001000;3-801000000000000000000000001000;3-941010000000000000000000001000;3-10 1000000000000000000000001000;3-11 01000000000000000000001000;3-12 000000000000000000000001000;3-13 000000000000000000000001000;3-14 000000000000000000000001000;3-15 000000000000000000000001000;3-16 000000000000000000000001000;3-17  00000000000000000000001000;3-18                              ;4-5000000000000000000000001000   ;4-611010000000000000000000001000;4-710100000000000000000000001000;4-801000000000000000000000001000;4-941010000000000000000000001000;4-10 1000000000000000000000001000;4-11 01000000000000000000001000;4-12 000000000000000000000001000;4-13 000000000000000000000001000;4-14 000000000000000000000001000;4-15 000000000000000000000001000;4-16 000000000000000000000001000;4-17  00000000000000000000001000;4-18                            ;5-611010000000000000000000001000;5-710100000000000000000000001000;5-801000000000000000000000001000;5-941010000000000000000000001000;5-10 1000000000000000000000001000;5-11 01000000000000000000001000;5-12 000000000000000000000001000;5-13 000000000000000000000001000;5-14 000000000000000000000001000;5-15 000000000000000000000001000;5-16 000000000000000000000001000;5-17  00000000000000000000001000;5-18                            ;6-710100000000000000000000001000;6-801000000000000000000000001000;6-941010000000000000000000001000;6-10 1000000000000000000000001000;6-11 01000000000000000000001000;6-12 000000000000000000000001000;6-13 000000000000000000000001000;6-14 000000000000000000000001000;6-15 000000000000000000000001000;6-16 000000000000000000000001000;6-17  00000000000000000000001000;6-18                           ;7-801000000000000000000000001000;7-941010000000000000000000001000;7-10 1000000000000000000000001000;7-11 01000000000000000000001000;7-12 000000000000000000000001000;7-13 000000000000000000000001000;7-14 000000000000000000000001000;7-15 000000000000000000000001000;7-16 000000000000000000000001000;7-17  00000000000000000000001000;7-18                           ;8-941010000000000000000000001000;8-10 1000000000000000000000001000 ;8-11 01000000000000000000001000;8-12 000000000000000000000001000;8-13 000000000000000000000001000;8-14 000000000000000000000001000;8-15 000000000000000000000001000;8-16 000000000000000000000001000;8-17  00000000000000000000001000;8-18                             ;9-10 1000000000000000000000001000;9-11 01000000000000000000001000;9-12 000000000000000000000001000;9-13 000000000000000000000001000;9-14 000000000000000000000001000;9-15 000000000000000000000001000;9-16 000000000000000000000001000;9-17  00000000000000000000001000;9-18 "                         10-11 01000000000000000000001000;10-12 000000000000000000000001000;10-13 000000000000000000000001000;10-14 000000000000000000000001000;10-15 000000000000000000000001000;10-16 000000000000000000000001000;10-17  00000000000000000000001000;10-18                       ;11-12 000000000000000000000001000;11-13 0000000000000000000001000;11-14 0000000000000000000001000;11-15 000000000000000000000001000;11-16 000000000000000000000001000;11-17  00000000000000000000001000;11-18                          ;12-13 0000000000000000000001000;12-14 0000000000000000000001000;12-15 000000000000000000000001000;12-16 000000000000000000000001000;12-17  00000000000000000000001000;12-18                         13-14 0000000000000000000001000;13-15 000000000000000000000001000;13-16 000000000000000000000001000;13-17  00000000000000000000001000;13-18                         ;14-15 000000000000000000000001000;14-16 000000000000000000000001000;14-17  00000000000000000000001000;14-18                         ;15-16 000000000000000000000001000;15-17  00000000000000000000001000;15-18                         ;16-17  00000000000000000000001000;16-18                         ;17-18
		String path2 = "01010110010101001000010001010000;10100000001000101000001000000010;01100000000011000000000001011110;10100000101000011000001000000010 ;01101100000000000011000000000100;10101010101101000000101100000001;01100000000000000110001000000100;10100001001000000000001110000010;00110000000011101000000000111100;10100000000000000110000001100100;01011100001000000000000001010100;10010000001000000000001000000100;10010000000000101000001000000010;10100000000011000101000000001110;10100000001000110000001110000011;10100001001000000000001110000010;01010000010011000000000001011000;10010110010011000101000000000000;10011100000110100101010000000010;10010110000101100101010000000000;00001010000000000110001001011000;10011101000000001101110100000010;10010110010011000101000000000000;10010111000101000101100100000000;01010110010011000000000001010000;11001010000000000000001001011000;00001010000000000101001000001000;10100110001101100101010000000000;00000110000011000000000000110010;10010110010011000101000000000000;10010110100101000101100100000001;10010110100101000101100100000001;00001100000011000000000000001010;00001010001101100000010000000100;00000000110000011000000000000000;01010000010011000111000000001000;00000001010110000000100100000000;10010000010011000101000000001000;00001011001101000000100100000100;01010000010011000000000001011000;01010000010011000000000001011000;10010000010011000101000000001000;00110000010000000000000000000110;10010000010000000000001000000110;00000000001000101000000000000110;00000000010000110000000110000001;00000000110000000000000110000001;10010000010011000101000000001000;00001010001101100000010000000100;10010000000101100101010000001000;00001011001011001000110100000100;10010000000101100101010000001000;00001011001101000000100100000100;01010000000101100000010001011000;01010000000101100000010001011000;10010000000101100101010000001000;10101010001101100000011000000000;00001010001101100000010000000110;00001010000101000000100010000010;00001010101101000000100100000101;00001010101101000000100100000101;10011010000110100101010000001010;01010000000101100011010000001000;00000000000110011000100100000001;10010000000101100101010000001000;00000000010110110000100100000001;01010000000101100000010001011000;01010000000101100000010001011000;10010000000101100101010000001000;00110000100000011000000000000110;00001010001101100000010000000100;00000000010110100000010000000000;00000000100000101000000110000001;00000000100000101000000110000001;10010000000101100101010000001000;01010001000101000011100100001000;11001100000000000011001000000000;01010001000101000011100100001000;00000000000000000011000001010000;11000000000000000101000001010000;00001100000000000110001001010000;01100000011011000011000000001000;01101100000000000011000000000100;01010000010011000011000000001000;01010000100101000011100100001001;01010000100101000011100100001001;00000000000011000110001001011010;10010001000101000101100100001000;00000001010110000000100100000000;00010001000101000000100101011000;01010001000101000000100101011000;01010001000101000000100101011000;10100001001101000101100100001000;00001011001101000000100100000100;00000001010110000000100100000000;00000000110110000000100100000001;00000000110110000000100100000001;10010001000101000101100100001000;10100001001101000101100100001000;11000000000000000101000001010000;11000000000000000000001001100000;11001100000000000000001001010000;01010000000000000110001000000100;10101100000000000101000000000100;10010000010011000101000000001000;10010000100101000101100100001001;10010000100101000101100100001001;10010000010011000110000001011000;01010001000101000000100101011000;01010001000101000000100101011000;10010001000101000101100100001000;10100001001101000101100100001000;00001011001101000000100100000100;00000001010110000000100100000000;00000000100000110000110100000001;00000001000000111000110010000001;10010001000101000101100100001000;11000000000000000011001000110000;01010000010011000000000001011000;01100000011011000000000001011000;00001100000000000110001001010000;01010000010011000000000001011000;01010000100101000000100101011001;01010000100101000000100101011001;01010000010011000000000001011000;11001100000000000000001001010000;01100000000000000000000001100100;01101100000000000000000001010100;01010000010011000000000001011000;01010000100101000000100101011001;00000000000101000000100101011000;01010000010011000000000001011000;01100000011011000000000001011000;00000000000011000000000000111010;10010000010011000101000000001000;10010000100101000101100100001001;10010001100101000101100100001001;00000000000011000000000000111010;10100000011000000000001000000010;00110000000000101000000000000110;00110000100000000000000110000111;00110000100000000000000110000111;10100000011011000101000000001000;00001010011011000000000000000100;00001010101101000000100100000101;00001010101101000000100100000101;00000000000011000000000000111010;00000000110000000000000110000001;00000000000000011000000110000001;10010000010011000101000000001000;00000001100000011000000110000000;10010000100101000101100100001001;10010000100101000101100100001001";//getParameter("backup");//"00000 00000 00000 00000 00000 00000 00//
		StringTokenizer t2 = new StringTokenizer(path2,";");
                
		String str1,str2;
		for (int i=0; i <panel.nnodes-1; i++){
			for (int j=i+1; j <panel.nnodes; j++)
                        {
				str1 = t1.nextToken();
                                
				str2 = t2.nextToken();
                                
				panel.addFlow(i, j, str1, str2);
			}
		}
    
	}
       catch(Exception e){}  
}
   
    public void destroy() {
        remove(panel);
        remove(controlPanel);
    }

    public void start() {
	panel.start();
    }

    public void stop() {
	panel.stop();
    }

    public void actionPerformed(ActionEvent e) {
	Object src = e.getSource();

	if (src == state) {
		StringBuffer x = new StringBuffer(); 
		double minx = 400, miny=400,maxx=0,maxy=0;
	    for (int i = 0 ; i < panel.nnodes ; i++) {
			panel.nodes[i].fixed = true;
			minx = Math.min(minx,panel.nodes[i].x);
			maxx = Math.max(maxx,panel.nodes[i].x);
			miny = Math.min(miny,panel.nodes[i].y);
			maxy = Math.max(maxy,panel.nodes[i].y);
			x= x.append("\\rput(")
				.append(Math.floor(panel.nodes[i].x)).append(",")
				  .append(-Math.floor(panel.nodes[i].y)).append("){\\rnode{n")
				  .append(i+1).append("}{\\pscirclebox{")
				.append(i+1).append("}}} ");
		}
		for (int i = 0; i < panel.nedges ; i++) {
			x = x.append("\\ncline{n").append(panel.edges[i].from+1)
				 .append("}{n").append(panel.edges[i].to+1)
				 .append("} ");
		}
		String c = "\\pspicture*("+Math.floor(minx-15)
				   +","+Math.floor(-miny+15)
				   +")(" + Math.floor(maxx+15) 
				   + ","+ Math.floor(-maxy-15) +") "
			+x.toString();
//		loc.setText(c);
		topo = !topo;
//		loc.setEnabled(topo);
		scramble.setEnabled(!topo);
		shake.setEnabled(!topo);
		stress.setEnabled(!topo);
		random.setEnabled(!topo);
		
		if (topo)
			state.setLabel("Show Paths");
                
                
		else 
			state.setLabel("Topology");
                
		
		return;
	}
       

	if (src == scramble) {
	  //  play(getCodeBase(), "audio/computer.au");
	    Dimension d = getSize();
	    for (int i = 0 ; i < panel.nnodes ; i++) {
		Node n = panel.nodes[i];
		if (!n.fixed) {
		    n.x = 10 + (d.width-20)*Math.random();
		    n.y = 10 + (d.height-20)*Math.random();
		}
	    }
	    return;
	}
	if (src == shake) 
        {
	    //play(getCodeBase(), "audio/gong.au");
	    Dimension d = getSize();
	    for (int i = 0 ; i < panel.nnodes ; i++)
            {
		Node n = panel.nodes[i];
		if (!n.fixed) 
                {
		    n.x += 80*Math.random() - 40;
		    n.y += 80*Math.random() - 40;
		}
                
	    }
            
	}
       /* if(src==next)
                {
                 String savedstis=t1.getText();
                 String savedsbpl=t2.getText();
                 System.out.print(savedsbpl);
                }*/
        

    }

    public void itemStateChanged(ItemEvent e) {
	Object src = e.getSource();
	boolean on = e.getStateChange() == ItemEvent.SELECTED;
	if (src == stress) panel.stress = on;
	else if (src == random) panel.random = on;
    }

    public String getAppletInfo() {
	return "Title: GraphLayout \nAuthor: Yu Liu <yuliu@tele.pitt.edu>";
    }

    public String[][] getParameterInfo() {
	String[][] info = {
	    {"edges", "delimited string", "A comma-delimited list of all the edges.  It takes the form of 'C-N1,C-N2,C-N3,C-NX,N1-N2/M12,N2-N3/M23,N3-NX/M3X,...' where C is the name of center node (see 'center' parameter) and NX is a node attached to the center node.  For the edges connecting nodes to eachother (and not to the center node) you may (optionally) specify a length MXY separated from the edge name by a forward slash."},
	    {"center", "string", "The name of the center node."},
		{"fixed", "string:x:y,...,string:x:y", "The names and locations of the fixed nodes."}
	};
	return info;
    }

}

